.. figure:: _static/livvkit.png
    :width: 400px
    :align: center
    :alt: LIVVkit

References and indices
======================

References
----------

.. [Evans2019] Evans, K. J., et al. (2019), LIVVkit 2.1: Automated and extensible ice sheet model validation,
    Geosci. Model Dev., 12, 1067–1086,
    `DOI:10.5194/gmd-12-1067-2019 <https://doi.org/10.5194/gmd-12-1067-2019>`__.


.. [Kennedy2017] Kennedy, J.H., et al. (2017), LIVVkit: An extensible, Python-based, land ice
    verification and validation toolkit for ice sheet models, J. Adv. Model. Earth Syst., 9,
    `DOI:10.1002/2017MS000916 <http://dx.doi.org/10.1002/2017MS000916>`__.

.. [Oberkampf2010] Oberkampf, W. L., & Roy, C. J. (2010). Verification and Validation
    in Scientific Computing. Cambridge University Press,
    `DOI:10.1017/CBO9780511760396 <https://doi.org/10.1017/CBO9780511760396>`__,
    `ISBN:9780511760396 <http://www.worldcat.org/oclc/933219483>`_

.. [Roache1998] Roache., P.J. (1998). Verification and Validation in Computational \
    Science and Engineering. Hermosa Publishers, Albuquerque, New Mexico,
    `ISBN:9780913478080 <http://www.worldcat.org/oclc/440878443>`__.


Indices
-------

* :ref:`genindex`
* :ref:`modindex`
